@@ -1,6 +1,9 @@
 package Sub::Monkey;
 
-our $VERSION = '0.002';
+use strict;
+use warnings;
+
+our $VERSION = '0.004';
 $Sub::Monkey::Subs     = {};
 $Sub::Monkey::CanPatch = [];
 $Sub::Monkey::Classes  = [];
@@ -10,6 +13,11 @@ $Sub::Monkey::Iter     = 0;
 
 Sub::Monkey - Dynamically and neatly monkey patch a module
 
+=head1 DEPRECATED
+
+Please note this module will not be maintained anymore. Instead, please check out C<Class::Monkey>. It's the same project with updated pod and newed methods. Not to mention a namespace that makes a bit more sense..
+Code you've made with Sub::Monkey will not break, just change the file where it's used as such: C<s/Sub::Monkey/Class::Monkey/g> and you're sorted.
+
 =head1 DESCRIPTION
 
 In some cases, rare cases, you may need to temporarily patch a module on-the-go. Sub::Monkey can help you achieve this by providing a set of methods to create, override and add hook modifiers, similar to M<Moose>, but can apply them to remote modules (Not the current one).
@@ -55,6 +63,7 @@ sub import {
             around
             unpatch
             instance
+            original
         /
     );
 }
@@ -82,6 +91,7 @@ sub _extend_class {
 
 sub _import_def {
     my ($pkg, $from, @subs) = @_;
+    no strict 'refs';
     if ($from) {
         for (@subs) {
             *{$pkg . "::$_"} = \&{"$from\::$_"};
@@ -113,6 +123,8 @@ sub _add_to_subs {
     if (! exists $Sub::Monkey::Subs->{$sub}) {
         $Sub::Monkey::Subs->{$sub} = {};
         $Sub::Monkey::Subs->{$sub} = \&{$sub};
+        no strict 'refs';
+        *{__PACKAGE__ . "::$sub"} = \&{$sub};
     }
 }
 
@@ -143,7 +155,7 @@ Patch an instance method instead of an entire class
     },
     $pig2;
 
-    # only C<$pig2> will have its says method overridden
+    # only $pig2 will have its says method overridden
 
 =cut
 
@@ -157,6 +169,35 @@ sub instance {
     bless $_[2], $package;
 }
 
+=head2 original
+
+If you want to run the original version of a patched method, but not unpatch it right away 
+you can use C<original> to do so. It will run the old method before it was patched with any arguments you specify, but the actual method will still remain patched.
+
+    after 'someMethod' => sub {
+        print "Blah\n"
+    },
+    qw<Foo>;
+
+    original('Foo', 'someMethod', qw<these are my args>);
+
+OR if you prefer, you can just call C<Sub::Monkey::PatchedClassName::method->(@args)>
+
+    Sub::Monkey::Foo->someMethod('these', 'are', 'my', 'args);
+
+=cut
+
+sub original {
+    my ($class, $method, @args) = @_;
+    if (exists $Sub::Monkey::Subs->{"$class\::$method"}) {
+        $Sub::Monkey::Subs->{"$class\::$method"}->(@args);
+    }
+    else {
+        warn "Could not run original method '$method' in class $class. Not found";
+        return 0;
+    }
+}
+
 =head2 override 
 
 Overrides an already existing method. If the target method doesn't exist then Sub::Monkey will throw an error.
@@ -180,6 +221,7 @@ sub override {
         if ! $class->can($method);
 
     _add_to_subs("$class\::$method");
+    no strict 'refs';
     *$method = sub { $code->(@_) };
     *{$class . "::$method"} = \*$method;
 }
@@ -207,6 +249,7 @@ sub method {
         if $class->can($method);
 
     _add_to_subs("$class\::$method");
+    no strict 'refs';
     *$method = sub { $code->(@_); };
 
     *{$class . "::$method"} = \*$method;
@@ -241,6 +284,7 @@ sub before {
     my ($method, $code, $class) = @_;
     
     _check_init($class);
+    my $full;
     if (ref($method) eq 'ARRAY') {
         for my $subname (@$method) {
             $full = "$class\::$subname";
@@ -251,6 +295,7 @@ sub before {
                 if ! $class->can($subname);
 
             $old_code = \&{$full};
+            no strict 'refs';
             *$subname = sub {
                 $code->(@_);
                 $old_code->(@_);
@@ -269,6 +314,7 @@ sub before {
             if ! $class->can($method);
 
         $old_code = \&{$full};
+        no strict 'refs';
         *$method = sub {
             $code->(@_);
             $old_code->(@_);
@@ -289,7 +335,7 @@ sub after {
     my ($method, $code, $class) = @_;
 
     _check_init($class);
-    $full = "$class\::$method";
+    my $full = "$class\::$method";
     my $alter_sub;
     my $new_code;
     my $old_code;
@@ -297,6 +343,7 @@ sub after {
         if ! $class->can($method);
 
     $old_code = \&{$full};
+    no strict 'refs';
     *$method = sub {
         $old_code->(@_);
         $code->(@_);
@@ -339,11 +386,12 @@ Around gives the user a bit more control over the subroutine. When you create an
 sub around {
     my ($method, $code, $class) = @_;
 
-    $full = "$class\::$method";
+    my $full = "$class\::$method";
     die "Could not find $method in the hierarchy for $class\n"
         if ! $class->can($method);
 
     my $old_code = \&{$full};
+    no strict 'refs';
     *$method = sub {
         $code->($old_code, @_);
     };
@@ -372,6 +420,7 @@ sub unpatch {
         return 0;
     }
 
+    no strict 'refs';
     *{$sub} = $Sub::Monkey::Subs->{$sub};
 }
 
